summaryrefslogtreecommitdiffstats
path: root/kshowmail/kcmconfigs/configaccounts.h
diff options
context:
space:
mode:
Diffstat (limited to 'kshowmail/kcmconfigs/configaccounts.h')
-rw-r--r--kshowmail/kcmconfigs/configaccounts.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/kshowmail/kcmconfigs/configaccounts.h b/kshowmail/kcmconfigs/configaccounts.h
index e2f4e53..047c262 100644
--- a/kshowmail/kcmconfigs/configaccounts.h
+++ b/kshowmail/kcmconfigs/configaccounts.h
@@ -12,18 +12,18 @@
#ifndef CONFIGACCOUNTS_H
#define CONFIGACCOUNTS_H
-//Qt headers
-#include <qlayout.h>
+//TQt headers
+#include <ntqlayout.h>
//KDE headers
-#include <kcmodule.h>
+#include <tdecmodule.h>
#include <kgenericfactory.h>
-#include <kapplication.h>
-#include <kconfig.h>
-#include <klistview.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
+#include <tdelistview.h>
#include <kpushbutton.h>
#include <kstdguiitem.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
//kshowmail headers
#include "../constants.h"
@@ -34,7 +34,7 @@
* @brief Part of the setup dialog (KShowMailApp::SetupDialog) to configure the accounts.
* @author Ulrich Weigelt <ulrich.weigelt@gmx.de>
*/
-class ConfigAccounts : public KCModule
+class ConfigAccounts : public TDECModule
{
Q_OBJECT
@@ -43,7 +43,7 @@ Q_OBJECT
/**
* Generic Constructor
*/
- ConfigAccounts( QWidget *parent = 0, const char *name = 0, const QStringList &args = QStringList() );
+ ConfigAccounts( TQWidget *parent = 0, const char *name = 0, const TQStringList &args = TQStringList() );
/**
* Destructor
@@ -51,21 +51,21 @@ Q_OBJECT
~ConfigAccounts();
/**
* Overloaded method of KCModule.
* Sets the user interface elements to reflect the current settings stored in the
* config file.
*/
virtual void load();
/**
* Overloaded method of KCModule.
* Sets the user interface elements to default values.
* This method is called when the user clicks the "Default" button.
*/
virtual void defaults();
/**
* Overloaded method of KCModule.
* Stores the config information as shown in the user interface in the
* config file.
* Is called when the user clicks "Apply" or "Ok".
@@ -77,12 +77,12 @@ Q_OBJECT
/**
* Connector to the configuration file
*/
- KConfig* config;
+ TDEConfig* config;
/**
* Account List View
*/
- KListView* AccountListView;
+ TDEListView* AccountListView;
/**
* Button to add a new account
@@ -103,7 +103,7 @@ Q_OBJECT
/**
* Connected with the configuration items.
* Calls the slot changed() of KCModule to notify the dialog about the change.
*/
void slotChanged();
@@ -51,21 +51,21 @@ Q_OBJECT
~ConfigAccounts();
/**
- * Overloaded method of KCModule.
+ * Overloaded method of TDECModule.
* Sets the user interface elements to reflect the current settings stored in the
* config file.
@@ -51,21 +51,21 @@ Q_OBJECT
virtual void load();
/**
- * Overloaded method of KCModule.
+ * Overloaded method of TDECModule.
* Sets the user interface elements to default values.
* This method is called when the user clicks the "Default" button.
@@ -51,21 +51,21 @@ Q_OBJECT
virtual void defaults();
/**
- * Overloaded method of KCModule.
+ * Overloaded method of TDECModule.
* Stores the config information as shown in the user interface in the
* config file.
@@ -103,7 +103,7 @@ Q_OBJECT
/**
* Connected with the configuration items.
- * Calls the slot changed() of KCModule to notify the dialog about the change.
+ * Calls the slot changed() of TDECModule to notify the dialog about the change.
*/
void slotChanged();